База даних порошкової дифракції — XRCEA 0.2 documentation

# База даних порошкової дифракції

`pddb.` `introduce`()

  Entry point. Declares menu items.

`pddb.` `terminate`()

  unloader

## Базові функції

db interface

class `pddb.pddb.` `Database`(path)

  Powder diffraction database class

  Параметри

    path (string) – Path to database.

  `execute`(command, commit=True)
    Параметри

      - command (string) – SQL command

      - commit (boolean) – Whether to commit results.

    Тип повернення

      list

  `select_bruqa`(req)

    Select bruto equation

    Параметри

      req (string) – Request

    Повертає

      list of cards

  `select_bruto`(req)

    Select bruto equation

    Параметри

      req (string) – Request

    Повертає

      list of cards

  `select_cards`(req)
    Параметри

      req (string) – Query to select cards

    Повертає

      List of cards.

  `select_reflex`(req)

    Select by reflex

    Параметри

      req (string) – Request

    Повертає

      list of cards

`pddb.pddb.` `formula_markup`(fstr, wiki=False)
  Параметри

    - fstr (string) – formula string

    - wiki (boolean) – print wiki (deprecated)

  Повертає

    formula

  Тип повернення

    string

`pddb.pddb.` `switch_number`(number)

  Adds defis to number.

  Параметри

    number (integer) – number in database

  Тип повернення

    string

## ГІК

class `pddb.browser.` `Browser`(db)
  `add_colored`(row, c=None)

    Add a card to colored

  `search`(query=None)

    Run search